# water-mesquite-greenhouse
Repository for "Trait responses of a grassland shrub invader to altered moisture regimes" manuscript

# Abstract

## Aims
We sought to identify plant traits important for initial establishment of a globally invasive shrub, _Prosopis_ spp. (mesquite), by quantifying morphological and ecophysiological responses of seedlings to contrasting moisture regimes. Our model plant was _Prosopis velutina_ (Woot.), a prominent invader of North American semi-desert grasslands.  

## Methods
Seedlings received one of three watering levels corresponding to regional ‘ambient’ (100%), ‘dry’ (-65%; 65% reduction of ambient), and ‘wet’ (+165%; 65% increase above ambient) growing season precipitation regimes. A total of 32 plant performance (e.g., biomass and growth) and functional (e.g., morphological and physiological) traits were assessed when seedlings reached ages of 11- and 22-days.  

## Results
Germination under dry conditions was high (72%) and only slightly reduced compared to ambient and wet conditions with subsequent seedling survival unaffected. High trait variation enabled early recruitment over the range of soil moisture conditions, including extreme drought. Root volume, surface area, tips, tap root length, and leaf length functional traits were top predictors of seedling performance, with fresh weight, absolute growth rate, and root mass secondarily contributing to establishment under altered moisture regimes.

## Conclusions
Shrub establishment in drylands, characterized by low and variable rainfall, is contingent on the ability of seedlings to exploit short-term windows of soil moisture availability. No physiological functional traits were significant in predicting performance or discriminating between moisture regimes; suggesting morphological traits for maintaining metabolic and hydraulic function are key to early establishment. Dry conditions reduced germination and slowed _P. velutina_ seedling growth but did not prevent early establishment. Thus, recruitment of certain dryland shrubs may not be episodic with respect to above-average rainfall. Indeed, early recruitment of _P. velutina_ and functionally similar species can potentially occur even in moisture conditions well below-average.


### Folder Info/Details
To open R scripts, run code, check output files, etc., clone the GitHub repository (in R terminal use `git clone https://github.com/warutherford/water-mesquite-greenhouse.git`) on your local machine with already Git installed and double-click the `GH_mesquite.Rproj` file to open the R project. Alternatively, you can download a `ZIP` folder of the entire repository and open the R project file under the `Code` tab above after unzipping/extracting the `ZIP` file. This assumes R/RStudio is currently installed on your machine.

All scripts for analyses in the paper are in the `Scripts` directory. For details on a specific script and it's purpose, see the `Scripts/README.md`.

Data for all analyses are in the `Data` directory. For details on a specific data set, see the `Data/README.md`.

Statistical outputs (descriptive stats, MANOVA, ANOVA, and post-hoc tests) are in the `Output` directory. For details on a specific stat output file, see the `Output/README.md`. 

The figures created in this manuscript are too large for GitHub, thus no `Figures` directory is provided in this repository. If you wish to write a figure to a `*.tiff` file using one of the scripts, you can either clone the repo locally and create a `Figures` directory, or you can change the file path in the script to your desired location/directory.
